@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ SearchDuplicatesPluginInterface::SearchDuplicatesPluginInterface(QObject *parent
 {
 }
 
-SearchDuplicatesPluginInterface::~SearchDuplicatesPluginInterface()
-{
-}
+SearchDuplicatesPluginInterface::~SearchDuplicatesPluginInterface() = default;
 
 void SearchDuplicatesPluginInterface::createAction(KActionCollection *ac)
 {
@@ -38,11 +36,9 @@ void SearchDuplicatesPluginInterface::slotActivated()
 
 void SearchDuplicatesPluginInterface::exec()
 {
-    QPointer<KABMergeContacts::SearchAndMergeContactDuplicateContactDialog> dlg =
-        new KABMergeContacts::SearchAndMergeContactDuplicateContactDialog(parentWidget());
-    dlg->searchPotentialDuplicateContacts(mListItems);
-    dlg->exec();
-    delete dlg;
+    KABMergeContacts::SearchAndMergeContactDuplicateContactDialog dlg(parentWidget());
+    dlg.searchPotentialDuplicateContacts(mListItems);
+    dlg.exec();
 }
 
 void SearchDuplicatesPluginInterface::setItems(const Akonadi::Item::List &items)
