@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -38,9 +38,7 @@ ConfirmBeforeDeletingWidget::ConfirmBeforeDeletingWidget(QWidget *parent)
     fillRules();
 }
 
-ConfirmBeforeDeletingWidget::~ConfirmBeforeDeletingWidget()
-{
-}
+ConfirmBeforeDeletingWidget::~ConfirmBeforeDeletingWidget() = default;
 
 void ConfirmBeforeDeletingWidget::fillRules()
 {
