@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,9 +31,7 @@ MarkdownConfigureWidget::MarkdownConfigureWidget(QWidget *parent)
     mainLayout->addStretch(1);
 }
 
-MarkdownConfigureWidget::~MarkdownConfigureWidget()
-{
-}
+MarkdownConfigureWidget::~MarkdownConfigureWidget() = default;
 
 void MarkdownConfigureWidget::loadSettings()
 {
