@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,9 +23,7 @@ QuickTextPluginEditorInterface::QuickTextPluginEditorInterface(QObject *parent)
     updateSnippetsInfo();
 }
 
-QuickTextPluginEditorInterface::~QuickTextPluginEditorInterface()
-{
-}
+QuickTextPluginEditorInterface::~QuickTextPluginEditorInterface() = default;
 
 void QuickTextPluginEditorInterface::updateSnippetsInfo()
 {
