@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,9 +25,7 @@ CheckBeforeSendInterface::CheckBeforeSendInterface(QObject *parent)
 {
 }
 
-CheckBeforeSendInterface::~CheckBeforeSendInterface()
-{
-}
+CheckBeforeSendInterface::~CheckBeforeSendInterface() = default;
 
 bool CheckBeforeSendInterface::exec(const MessageComposer::PluginEditorCheckBeforeSendParams &params)
 {
