@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,13 +8,9 @@
 #include <KEmailAddress>
 #include <PimCommon/PimUtil>
 
-CheckDuplicateEmailsJob::CheckDuplicateEmailsJob()
-{
-}
+CheckDuplicateEmailsJob::CheckDuplicateEmailsJob() = default;
 
-CheckDuplicateEmailsJob::~CheckDuplicateEmailsJob()
-{
-}
+CheckDuplicateEmailsJob::~CheckDuplicateEmailsJob() = default;
 
 void CheckDuplicateEmailsJob::start()
 {
