@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -14,9 +14,7 @@ CsvWidgetTest::CsvWidgetTest(QObject *parent)
 {
 }
 
-CsvWidgetTest::~CsvWidgetTest()
-{
-}
+CsvWidgetTest::~CsvWidgetTest() = default;
 
 void CsvWidgetTest::shouldHaveDefaultValue()
 {
