@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -11,6 +11,4 @@ MailMergeMenu::MailMergeMenu(QWidget *parent)
 {
 }
 
-MailMergeMenu::~MailMergeMenu()
-{
-}
+MailMergeMenu::~MailMergeMenu() = default;
