@@ -8,9 +8,15 @@
 
 #include <KContacts/Address>
 #include <KItinerary/Place>
+#include <kcontacts_version.h>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/exception.h>
 #include <grantlee/parser.h>
+#else
+#include <KTextTemplate/exception.h>
+#include <KTextTemplate/parser.h>
+#endif
 
 #include <QDateTime>
 #include <QTimeZone>
@@ -30,9 +36,13 @@ QVariant AddressFormatter::doFilter(const QVariant &input, const QVariant &arg,
     address.setPostalCode(a.postalCode());
     address.setLocality(a.addressLocality());
     address.setRegion(a.addressRegion());
-    address.setCountry(KContacts::Address::ISOtoCountry(a.addressCountry()));
+    address.setCountry(a.addressCountry());
 
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 92, 0)
     auto s = escape(address.formattedAddress().trimmed().replace(QLatin1String("\n\n"), QLatin1String("\n")));
+#else
+    auto s = escape(address.formatted(KContacts::AddressFormatStyle::MultiLineInternational));
+#endif
     return s.get().replace(QLatin1Char('\n'), QLatin1String("<br/>"));
 }
 
@@ -92,11 +102,18 @@ TagLibrary::TagLibrary(QObject *parent)
     : QObject(parent)
 {
 }
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 QHash<QString, Grantlee::Filter *> TagLibrary::filters(const QString &name)
+#else
+QHash<QString, KTextTemplate::Filter *> TagLibrary::filters(const QString &name)
+#endif
 {
     Q_UNUSED(name)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QHash<QString, Grantlee::Filter *> filters;
+#else
+    QHash<QString, KTextTemplate::Filter *> filters;
+#endif
     filters.insert(QStringLiteral("formatAddress"), new AddressFormatter());
     filters.insert(QStringLiteral("formatDate"), new DateFormatter());
     filters.insert(QStringLiteral("formatDateTime"), new DateTimeFormatter());
