@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ FolderConfigureSettingsTemplateWidget::FolderConfigureSettingsTemplateWidget(QWi
     addMainWidget(mCollectionTemplateWidget);
 }
 
-FolderConfigureSettingsTemplateWidget::~FolderConfigureSettingsTemplateWidget()
-{
-}
+FolderConfigureSettingsTemplateWidget::~FolderConfigureSettingsTemplateWidget() = default;
 
 void FolderConfigureSettingsTemplateWidget::save(Akonadi::Collection &col)
 {
