@@ -3,15 +3,15 @@
 
     This file is part of KMail, the KDE mail client.
     SPDX-FileCopyrightText: 2003 Marc Mutz <mutz@kde.org>
-    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-only
 */
 
 #pragma once
 
-#include "headerstyle_util.h"
 #include <MessageViewer/HeaderStyle>
+#include <MessageViewer/HeaderStyle_Util>
 namespace MessageViewer
 {
 class BriefHeaderStyle : public HeaderStyle
@@ -22,9 +22,7 @@ public:
     {
     }
 
-    ~BriefHeaderStyle() override
-    {
-    }
+    ~BriefHeaderStyle() override = default;
 
 public:
     const char *name() const override
