@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,7 @@
 #include <Akonadi/ItemCreateJob>
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
-#include <Akonadi/KMime/MessageParts>
+#include <Akonadi/MessageParts>
 #include <Akonadi/RelationCreateJob>
 
 #include <KMime/Message>
@@ -24,9 +24,7 @@ CreateEventJob::CreateEventJob(const KCalendarCore::Event::Ptr &eventPtr, const
 {
 }
 
-CreateEventJob::~CreateEventJob()
-{
-}
+CreateEventJob::~CreateEventJob() = default;
 
 void CreateEventJob::start()
 {
