@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,9 +25,7 @@ ViewerPluginCreatenoteInterface::ViewerPluginCreatenoteInterface(KActionCollecti
     createAction(ac);
 }
 
-ViewerPluginCreatenoteInterface::~ViewerPluginCreatenoteInterface()
-{
-}
+ViewerPluginCreatenoteInterface::~ViewerPluginCreatenoteInterface() = default;
 
 void ViewerPluginCreatenoteInterface::setText(const QString &text)
 {
